==> huaweicloudsdkiam-3.0.46-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/associate_agency_with_project_permission_request.py <==
# coding: utf-8

import pprint
import re

import six





class AssociateAgencyWithProjectPermissionRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'project_id': 'str',
        'agency_id': 'str',
        'role_id': 'str'
    }

    attribute_map = {
        'project_id': 'project_id',
        'agency_id': 'agency_id',
        'role_id': 'role_id'
    }

    def __init__(self, project_id=None, agency_id=None, role_id=None):
        """AssociateAgencyWithProjectPermissionRequest - a model defined in huaweicloud sdk"""
        
        

        self._project_id = None
        self._agency_id = None
        self._role_id = None
        self.discriminator = None

        self.project_id = project_id
        self.agency_id = agency_id
        self.role_id = role_id

    @property
    def project_id(self):
        """Gets the project_id of this AssociateAgencyWithProjectPermissionRequest.

        委托方的项目ID，获取方式请参见：[获取项目名称、项目ID](https://support.huaweicloud.com/api-iam/iam_17_0002.html)。

        :return: The project_id of this AssociateAgencyWithProjectPermissionRequest.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this AssociateAgencyWithProjectPermissionRequest.

        委托方的项目ID，获取方式请参见：[获取项目名称、项目ID](https://support.huaweicloud.com/api-iam/iam_17_0002.html)。

        :param project_id: The project_id of this AssociateAgencyWithProjectPermissionRequest.
        :type: str
        """
        self._project_id = project_id

    @property
    def agency_id(self):
        """Gets the agency_id of this AssociateAgencyWithProjectPermissionRequest.

        委托ID，获取方式请参见：[获取委托名、委托ID](https://support.huaweicloud.com/api-iam/iam_17_0002.html)。

        :return: The agency_id of this AssociateAgencyWithProjectPermissionRequest.
        :rtype: str
        """
        return self._agency_id

    @agency_id.setter
    def agency_id(self, agency_id):
        """Sets the agency_id of this AssociateAgencyWithProjectPermissionRequest.

        委托ID，获取方式请参见：[获取委托名、委托ID](https://support.huaweicloud.com/api-iam/iam_17_0002.html)。

        :param agency_id: The agency_id of this AssociateAgencyWithProjectPermissionRequest.
        :type: str
        """
        self._agency_id = agency_id

    @property
    def role_id(self):
        """Gets the role_id of this AssociateAgencyWithProjectPermissionRequest.

        权限ID，获取方式请参见：[获取权限名、权限ID](https://support.huaweicloud.com/api-iam/iam_10_0001.html)。

        :return: The role_id of this AssociateAgencyWithProjectPermissionRequest.
        :rtype: str
        """
        return self._role_id

    @role_id.setter
    def role_id(self, role_id):
        """Sets the role_id of this AssociateAgencyWithProjectPermissionRequest.

        权限ID，获取方式请参见：[获取权限名、权限ID](https://support.huaweicloud.com/api-iam/iam_10_0001.html)。

        :param role_id: The role_id of this AssociateAgencyWithProjectPermissionRequest.
        :type: str
        """
        self._role_id = role_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssociateAgencyWithProjectPermissionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiam-3.0.52-py2.py3-none-any.whl: huaweicloudsdkiam/v3/model/associate_agency_with_project_permission_request.py <==
# coding: utf-8

import re
import six





class AssociateAgencyWithProjectPermissionRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'project_id': 'str',
        'agency_id': 'str',
        'role_id': 'str'
    }

    attribute_map = {
        'project_id': 'project_id',
        'agency_id': 'agency_id',
        'role_id': 'role_id'
    }

    def __init__(self, project_id=None, agency_id=None, role_id=None):
        """AssociateAgencyWithProjectPermissionRequest - a model defined in huaweicloud sdk"""
        
        

        self._project_id = None
        self._agency_id = None
        self._role_id = None
        self.discriminator = None

        self.project_id = project_id
        self.agency_id = agency_id
        self.role_id = role_id

    @property
    def project_id(self):
        """Gets the project_id of this AssociateAgencyWithProjectPermissionRequest.

        委托方的项目ID，获取方式请参见：[获取项目名称、项目ID](https://support.huaweicloud.com/api-iam/iam_17_0002.html)。

        :return: The project_id of this AssociateAgencyWithProjectPermissionRequest.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this AssociateAgencyWithProjectPermissionRequest.

        委托方的项目ID，获取方式请参见：[获取项目名称、项目ID](https://support.huaweicloud.com/api-iam/iam_17_0002.html)。

        :param project_id: The project_id of this AssociateAgencyWithProjectPermissionRequest.
        :type: str
        """
        self._project_id = project_id

    @property
    def agency_id(self):
        """Gets the agency_id of this AssociateAgencyWithProjectPermissionRequest.

        委托ID，获取方式请参见：[获取委托名、委托ID](https://support.huaweicloud.com/api-iam/iam_17_0002.html)。

        :return: The agency_id of this AssociateAgencyWithProjectPermissionRequest.
        :rtype: str
        """
        return self._agency_id

    @agency_id.setter
    def agency_id(self, agency_id):
        """Sets the agency_id of this AssociateAgencyWithProjectPermissionRequest.

        委托ID，获取方式请参见：[获取委托名、委托ID](https://support.huaweicloud.com/api-iam/iam_17_0002.html)。

        :param agency_id: The agency_id of this AssociateAgencyWithProjectPermissionRequest.
        :type: str
        """
        self._agency_id = agency_id

    @property
    def role_id(self):
        """Gets the role_id of this AssociateAgencyWithProjectPermissionRequest.

        权限ID，获取方式请参见：[获取权限名、权限ID](https://support.huaweicloud.com/api-iam/iam_10_0001.html)。

        :return: The role_id of this AssociateAgencyWithProjectPermissionRequest.
        :rtype: str
        """
        return self._role_id

    @role_id.setter
    def role_id(self, role_id):
        """Sets the role_id of this AssociateAgencyWithProjectPermissionRequest.

        权限ID，获取方式请参见：[获取权限名、权限ID](https://support.huaweicloud.com/api-iam/iam_10_0001.html)。

        :param role_id: The role_id of this AssociateAgencyWithProjectPermissionRequest.
        :type: str
        """
        self._role_id = role_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssociateAgencyWithProjectPermissionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
